==> MuSE-0.7pre1.tar.gz: MuSE-0.7pre1/gtkgui/mp3file.cpp <==
/* A Gui in gtk+ for MuSE - Multiple Streaming Engine
 * Copyright (C) 2002 nightolo <night@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <stdlib.h>
#include <gtk/gtk.h>

#include "generic.h"
#include "profile.h"
#include "gchan.h" /* FIXME: delete fileseldel */
#include "mp3file.h"

#include <jutils.h>
#include <jmixer.h>
#include <config.h>

void spawnmp3file(GtkWidget *w)
{
	GtkWidget *filew;

	filew=gtk_file_selection_new("Create your mp3 file into a dir");
	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(filew)->ok_button),
			"clicked", (GtkSignalFunc) setmp3entry, filew);
	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(filew)->cancel_button),
			"clicked", (GtkSignalFunc) fileseldel, filew);
	gtk_signal_connect(GTK_OBJECT(filew), "destroy",
			(GtkSignalFunc) fileseldel, filew);

	gtk_widget_show(filew);

}

void setmp3entry(GtkWidget *w, GtkFileSelection *fw)
{	
	char *pd;

	pd=gtk_file_selection_get_filename(GTK_FILE_SELECTION(fw));
	gtk_entry_set_text(GTK_ENTRY(mp3entry), pd);
	gtk_widget_destroy(GTK_WIDGET(fw));
	
}

GtkWidget *setmp3file(GtkWidget *w)
{
	GtkWidget *verbox, *hbox, *filesel, *start;
	
	verbox=gtk_vbox_new(FALSE, 0);
	hbox=gtk_hbox_new(FALSE, 0);
	gtk_box_pack_start(GTK_BOX(verbox), hbox, FALSE, FALSE, 0);
	gtk_container_set_border_width(GTK_CONTAINER(hbox), 20);
	
/*	table=gtk_table_new(1, 3, FALSE);
	gtk_box_pack_start(GTK_BOX(hbox), table, FALSE, FALSE, 0);*/

	mp3entry=gtk_entry_new();
	gtk_box_pack_start(GTK_BOX(hbox), mp3entry, FALSE, FALSE, 0);
	/*gtk_table_attach_defaults(GTK_TABLE(table), mp3entry, 0, 1, 0, 1);*/
	
	filesel=gtk_button_new_with_label("Browse...");
	gtk_signal_connect(GTK_OBJECT(filesel), "clicked",
			(GtkSignalFunc) spawnmp3file, NULL);
	gtk_box_pack_start(GTK_BOX(hbox), filesel, FALSE, FALSE, 0);
/*	gtk_table_attach_defaults(GTK_TABLE(table), filesel, 1, 2, 0,
 *	1);*/
	
	start=gtk_toggle_button_new_with_label("Record now!");
	if(mixer->fileout)
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(start), TRUE);
	gtk_signal_connect(GTK_OBJECT(start), "clicked",
			(GtkSignalFunc) gcb_set_mp3file, NULL);
	gtk_box_pack_start(GTK_BOX(hbox), start, FALSE, FALSE, 0);
/*	gtk_table_attach_defaults(GTK_TABLE(table), start, 2, 3, 0, 1);*/

	return verbox;
}

void gcb_set_mp3file(GtkWidget *w)
{
	char *file;
	
	if(!lametmp->status) { 
		/* is encoder configured? */
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), FALSE);
		func("gcb_set_mp3file:: You must configure your encoder");
		gtk_notebook_set_page(GTK_NOTEBOOK(nbook), 1);
		return; 
	}
	
	/* FIXME: gtk_editable_get_chars , free pointer */
	if(GTK_TOGGLE_BUTTON(w)->active) {
		file=gtk_entry_get_text(GTK_ENTRY(mp3entry));
		notice("gcb_set_mp3file::mixer->set_mp3file(%s, %d)", file, guibitrate);	

		if((strlen(file)))
			mixer->set_mp3file(file, guibitrate);  
		else
			error("gcb_set_mp3file:: Not a valid filename", file, guibitrate);
	}
	else
		mixer->stop_mp3file();
}

==> MuSE-0.7.2.tar.gz: MuSE-0.7.2/gtkgui/mp3file.cpp <==
/* A Gui in gtk+ for MuSE - Multiple Streaming Engine
 * Copyright (C) 2002 nightolo <night@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <stdlib.h>
#include <gtk/gtk.h>

#include "generic.h"
#include <mp3file.h>

#include <jutils.h>
#include <jmixer.h>

#include <config.h>

void spawnmp3file(GtkWidget *w)
{
	GtkWidget *filew;

	filew=gtk_file_selection_new("Create your mp3 file into a dir");
	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(filew)->ok_button),
			"clicked", (GtkSignalFunc) setmp3entry, filew);
	gtk_signal_connect_object(GTK_OBJECT(
				GTK_FILE_SELECTION(filew)->cancel_button),
			"clicked", (GtkSignalFunc) gtk_widget_destroy, GTK_OBJECT(filew));
	gtk_signal_connect(GTK_OBJECT(filew), "destroy", 
			(GtkSignalFunc) gtk_widget_destroy, NULL);

	gtk_widget_show(filew);

}

void setmp3entry(GtkWidget *w, GtkFileSelection *fw)
{	
	char *pd;

	pd=gtk_file_selection_get_filename(GTK_FILE_SELECTION(fw));
	gtk_entry_set_text(GTK_ENTRY(mp3entry), pd);
	gtk_widget_destroy(GTK_WIDGET(fw));
	
}

GtkWidget *setmp3file(GtkWidget *w)
{
	GtkWidget *verbox, *hbox, *filesel, *start;
	
	verbox=gtk_vbox_new(FALSE, 0);
	hbox=gtk_hbox_new(FALSE, 0);
	gtk_box_pack_start(GTK_BOX(verbox), hbox, FALSE, FALSE, 0);
	gtk_container_set_border_width(GTK_CONTAINER(hbox), 20);
	
/*	table=gtk_table_new(1, 3, FALSE);
	gtk_box_pack_start(GTK_BOX(hbox), table, FALSE, FALSE, 0);*/

	mp3entry=gtk_entry_new();
	gtk_box_pack_start(GTK_BOX(hbox), mp3entry, FALSE, FALSE, 0);
	/*gtk_table_attach_defaults(GTK_TABLE(table), mp3entry, 0, 1, 0, 1);*/
	
	filesel=gtk_button_new_with_label("Browse...");
	gtk_signal_connect(GTK_OBJECT(filesel), "clicked",
			(GtkSignalFunc) spawnmp3file, NULL);
	gtk_box_pack_start(GTK_BOX(hbox), filesel, FALSE, FALSE, 0);
/*	gtk_table_attach_defaults(GTK_TABLE(table), filesel, 1, 2, 0,
 *	1);*/
	
	start=gtk_toggle_button_new_with_label("Record now!");
	if(mixer->fileout)
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(start), TRUE);
	gtk_signal_connect(GTK_OBJECT(start), "clicked",
			(GtkSignalFunc) gcb_set_mp3file, NULL);
	gtk_box_pack_start(GTK_BOX(hbox), start, FALSE, FALSE, 0);
/*	gtk_table_attach_defaults(GTK_TABLE(table), start, 2, 3, 0, 1);*/

	return verbox;
}

void gcb_set_mp3file(GtkWidget *w)
{
	char *file;
	/*	
	if(!lametmp->status) { 
		// is encoder configured?
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), FALSE);
		func("gcb_set_mp3file:: You must configure your encoder");
		gtk_notebook_set_page(GTK_NOTEBOOK(nbook), 1);
		return; 
	}
	*/
	if(GTK_TOGGLE_BUTTON(w)->active) {
		file=gtk_editable_get_chars(GTK_EDITABLE(mp3entry), 0, -1);
		notice("gcb_set_mp3file::mixer->set_mp3file(%s, %d)", file, lametmp.bps);	

		if((strlen(file)))
			mixer->set_mp3file(file, lametmp.bps);  
		else
			error("gcb_set_mp3file:: Not a valid filename", file, lametmp.bps);
		g_free(file);
	}
	else
		mixer->stop_mp3file();
}
